@@ -20,9 +20,11 @@
 #define G_LOG_DOMAIN "GcalWindow"
 
 #include "css-code.h"
+#include "gcal-agenda-view.h"
 #include "gcal-calendar-management-dialog.h"
 #include "gcal-calendar-button.h"
 #include "config.h"
+#include "gcal-date-chooser.h"
 #include "gcal-debug.h"
 #include "gcal-event-editor-dialog.h"
 #include "gcal-event-widget.h"
@@ -33,11 +35,11 @@
 #include "gcal-search-button.h"
 #include "gcal-timeline.h"
 #include "gcal-timeline-subscriber.h"
+#include "gcal-toolbar-end.h"
 #include "gcal-view.h"
 #include "gcal-weather-settings.h"
 #include "gcal-week-view.h"
 #include "gcal-window.h"
-#include "gcal-year-view.h"
 
 #include "importer/gcal-import-dialog.h"
 
@@ -101,21 +103,18 @@ struct _GcalWindow
   AdwViewStack       *views_stack;
   GtkWidget          *week_view;
   GtkWidget          *month_view;
-  GtkWidget          *year_view;
+  GtkWidget          *agenda_view;
+  GtkWidget          *date_chooser;
+  GtkWidget          *action_bar;
 
   /* header_bar widets */
-  GtkWidget          *back_button;
   GtkWidget          *calendars_button;
-  GtkWidget          *forward_button;
   GtkWidget          *menu_button;
-  GtkWidget          *today_button;
   GtkWidget          *views_switcher;
 
   GcalEventEditorDialog *event_editor;
   GtkWindow             *import_dialog;
 
-  GcalSearchButton   *search_button;
-
   /* new event popover widgets */
   GtkWidget          *quick_add_popover;
 
@@ -152,7 +151,6 @@ struct _GcalWindow
   gint                click_outside_handler_id;
 
   /* CSS */
-  GtkCssProvider     *provider;
   GtkCssProvider     *colors_provider;
 
   /* Window states */
@@ -179,10 +177,11 @@ static GParamSpec* properties[N_PROPS] = { NULL, };
  */
 
 static void
-update_today_button_sensitive (GcalWindow *window)
+update_today_action_enabled (GcalWindow *window)
 {
   g_autoptr (GDateTime) now = NULL;
-  gboolean sensitive;
+  GSimpleAction *action;
+  gboolean enabled;
 
   GCAL_ENTRY;
 
@@ -191,8 +190,8 @@ update_today_button_sensitive (GcalWindow *window)
   switch (window->active_view)
     {
     case GCAL_WINDOW_VIEW_WEEK:
-      sensitive = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
-                  g_date_time_get_week_of_year (window->active_date) !=  g_date_time_get_week_of_year (now);
+      enabled = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
+                g_date_time_get_week_of_year (window->active_date) !=  g_date_time_get_week_of_year (now);
 
       GCAL_TRACE_MSG ("Week: active date's week is %d, current week is %d",
                       g_date_time_get_week_of_year (window->active_date),
@@ -200,20 +199,17 @@ update_today_button_sensitive (GcalWindow *window)
       break;
 
     case GCAL_WINDOW_VIEW_MONTH:
-      sensitive = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
-                  g_date_time_get_month (window->active_date) != g_date_time_get_month (now);
-      break;
-
-    case GCAL_WINDOW_VIEW_YEAR:
-      sensitive = g_date_time_get_year (window->active_date) != g_date_time_get_year (now);
+      enabled = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
+                g_date_time_get_month (window->active_date) != g_date_time_get_month (now);
       break;
 
     default:
-      sensitive = TRUE;
+      enabled = TRUE;
       break;
     }
 
-  gtk_widget_set_sensitive (window->today_button, sensitive);
+  action = G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (window), "today"));
+  g_simple_action_set_enabled (action, enabled);
 
   GCAL_EXIT;
 }
@@ -230,7 +226,8 @@ maybe_add_subscribers_to_timeline (GcalWindow *self)
   timeline = gcal_manager_get_timeline (gcal_context_get_manager (self->context));
   gcal_timeline_add_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->week_view));
   gcal_timeline_add_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->month_view));
-  gcal_timeline_add_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->year_view));
+  gcal_timeline_add_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->agenda_view));
+  gcal_timeline_add_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->date_chooser));
 
   self->subscribed = TRUE;
 }
@@ -249,10 +246,12 @@ update_active_date (GcalWindow *window,
 
   gcal_set_date_time (&window->active_date, new_date);
 
-  for (i = GCAL_WINDOW_VIEW_WEEK; i <= GCAL_WINDOW_VIEW_YEAR; i++)
+  for (i = GCAL_WINDOW_VIEW_WEEK; i <= GCAL_WINDOW_VIEW_MONTH; i++)
     gcal_view_set_date (GCAL_VIEW (window->views[i]), new_date);
+  gcal_view_set_date (GCAL_VIEW (window->agenda_view), new_date);
+  gcal_view_set_date (GCAL_VIEW (window->date_chooser), new_date);
 
-  update_today_button_sensitive (window);
+  update_today_action_enabled (window);
 
   maybe_add_subscribers_to_timeline (window);
 
@@ -301,36 +300,15 @@ recalculate_calendar_colors_css (GcalWindow *self)
 static void
 load_css_providers (GcalWindow *self)
 {
-  g_autoptr (GFile) css_file = NULL;
-  g_autofree gchar *theme_name = NULL;
-  g_autofree gchar *theme_uri = NULL;
   GdkDisplay *display;
 
   display = gtk_widget_get_display (GTK_WIDGET (self));
 
-  /* Theme */
-  self->provider = gtk_css_provider_new ();
-  gtk_style_context_add_provider_for_display (display,
-                                              GTK_STYLE_PROVIDER (self->provider),
-                                              GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 1);
-
-  /* Retrieve the theme name */
-  g_object_get (gtk_settings_get_default (), "gtk-theme-name", &theme_name, NULL);
-  theme_uri = g_strconcat ("resource:///org/gnome/calendar/theme/", theme_name, ".css", NULL);
-
-  /* Try and load the CSS file */
-  css_file = g_file_new_for_uri (theme_uri);
-
-  if (g_file_query_exists (css_file, NULL))
-    gtk_css_provider_load_from_file (self->provider, css_file);
-  else
-    gtk_css_provider_load_from_resource (self->provider, "/org/gnome/calendar/theme/Adwaita.css");
-
   /* Calendar olors */
   self->colors_provider = gtk_css_provider_new ();
   gtk_style_context_add_provider_for_display (display,
                                               GTK_STYLE_PROVIDER (self->colors_provider),
-                                              GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 2);
+                                              GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 1);
 }
 
 
@@ -366,7 +344,7 @@ on_view_action_activated (GSimpleAction *action,
   else if (view == -2)
     view = --(window->active_view);
 
-  window->active_view = CLAMP (view, GCAL_WINDOW_VIEW_WEEK, GCAL_WINDOW_VIEW_YEAR);
+  window->active_view = CLAMP (view, GCAL_WINDOW_VIEW_WEEK, GCAL_WINDOW_VIEW_MONTH);
   adw_view_stack_set_visible_child (window->views_stack, window->views[window->active_view]);
 
   g_object_notify_by_pspec (G_OBJECT (user_data), properties[PROP_ACTIVE_VIEW]);
@@ -517,7 +495,7 @@ view_changed (GObject    *object,
   g_type_class_unref (eklass);
 
   window->active_view = view_type;
-  update_today_button_sensitive (window);
+  update_today_action_enabled (window);
   g_object_notify_by_pspec (G_OBJECT (user_data), properties[PROP_ACTIVE_VIEW]);
 }
 
@@ -660,6 +638,12 @@ event_preview_cb (GcalEventWidget        *event_widget,
     }
 }
 
+static void
+day_selected (GcalWindow *self)
+{
+  update_active_date (self, gcal_view_get_date (GCAL_VIEW (self->date_chooser)));
+}
+
 static void
 event_activated (GcalView        *view,
                  GcalEventWidget *event_widget,
@@ -702,6 +686,8 @@ on_event_editor_dialog_remove_event_cb (GcalEventEditorDialog *edit_dialog,
 {
   g_autoptr (AdwToast) toast = NULL;
   g_autoptr (GList) widgets = NULL;
+  g_autoptr (GList) agenda_view_widgets = NULL;
+  g_autoptr (GList) date_chooser_widgets = NULL;
   GcalView *view;
   gboolean has_deleted_event;
 
@@ -724,8 +710,12 @@ on_event_editor_dialog_remove_event_cb (GcalEventEditorDialog *edit_dialog,
   /* hide widget of the event */
   view = GCAL_VIEW (self->views[self->active_view]);
   widgets = gcal_view_get_children_by_uuid (view, modifier, gcal_event_get_uid (event));
+  agenda_view_widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->agenda_view), modifier, gcal_event_get_uid (event));
+  date_chooser_widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->date_chooser), modifier, gcal_event_get_uid (event));
 
   g_list_foreach (widgets, (GFunc) gtk_widget_hide, NULL);
+  g_list_foreach (agenda_view_widgets, (GFunc) gtk_widget_hide, NULL);
+  g_list_foreach (date_chooser_widgets, (GFunc) gtk_widget_hide, NULL);
 
   GCAL_EXIT;
 }
@@ -736,6 +726,8 @@ schedule_open_edit_dialog_by_uuid (OpenEditDialogData *edit_dialog_data)
   GcalWindow *window;
   GList *widgets;
 
+  /* FIXME Do that in the date chooser too? */
+
   window = edit_dialog_data->window;
   widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (window->month_view),
                                             GCAL_RECURRENCE_MOD_THIS_ONLY,
@@ -782,7 +774,6 @@ gcal_window_finalize (GObject *object)
   gcal_clear_date_time (&window->active_date);
 
   g_clear_object (&window->colors_provider);
-  g_clear_object (&window->provider);
 
   G_OBJECT_CLASS (gcal_window_parent_class)->finalize (object);
 
@@ -800,7 +791,8 @@ gcal_window_dispose (GObject *object)
   timeline = gcal_manager_get_timeline (gcal_context_get_manager (self->context));
   gcal_timeline_remove_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->week_view));
   gcal_timeline_remove_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->month_view));
-  gcal_timeline_remove_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->year_view));
+  gcal_timeline_remove_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->agenda_view));
+  gcal_timeline_remove_subscriber (timeline, GCAL_TIMELINE_SUBSCRIBER (self->date_chooser));
 
   g_clear_pointer (&self->quick_add_popover, gtk_widget_unparent);
 
@@ -845,10 +837,10 @@ gcal_window_constructed (GObject *object)
   g_object_bind_property (self, "context", self->calendar_management_dialog, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->week_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->month_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-  g_object_bind_property (self, "context", self->year_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->agenda_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->date_chooser, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->event_editor, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->quick_add_popover, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-  g_object_bind_property (self, "context", self->search_button, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
 
   /* CSS */
   load_css_providers (self);
@@ -973,16 +965,17 @@ gcal_window_class_init (GcalWindowClass *klass)
   GObjectClass *object_class;
   GtkWidgetClass *widget_class;
 
+  g_type_ensure (GCAL_TYPE_AGENDA_VIEW);
   g_type_ensure (GCAL_TYPE_CALENDAR_MANAGEMENT_DIALOG);
   g_type_ensure (GCAL_TYPE_CALENDAR_BUTTON);
+  g_type_ensure (GCAL_TYPE_DATE_CHOOSER);
   g_type_ensure (GCAL_TYPE_EVENT_EDITOR_DIALOG);
   g_type_ensure (GCAL_TYPE_MANAGER);
   g_type_ensure (GCAL_TYPE_MONTH_VIEW);
   g_type_ensure (GCAL_TYPE_QUICK_ADD_POPOVER);
-  g_type_ensure (GCAL_TYPE_SEARCH_BUTTON);
+  g_type_ensure (GCAL_TYPE_TOOLBAR_END);
   g_type_ensure (GCAL_TYPE_WEATHER_SETTINGS);
   g_type_ensure (GCAL_TYPE_WEEK_VIEW);
-  g_type_ensure (GCAL_TYPE_YEAR_VIEW);
 
   object_class = G_OBJECT_CLASS (klass);
   object_class->finalize = gcal_window_finalize;
@@ -1025,24 +1018,22 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/calendar/ui/gui/gcal-window.ui");
 
   /* widgets */
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, back_button);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, agenda_view);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendars_button);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, date_chooser);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, event_editor);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, forward_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, header_bar);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, main_box);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, menu_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, month_view);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, action_bar);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, quick_add_popover);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, search_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendar_management_dialog);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, today_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, overlay);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_stack);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_switcher);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, weather_settings);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, week_view);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, year_view);
 
   gtk_widget_class_bind_template_callback (widget_class, view_changed);
 
@@ -1051,6 +1042,7 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, create_event_detailed_cb);
   gtk_widget_class_bind_template_callback (widget_class, show_new_event_widget);
   gtk_widget_class_bind_template_callback (widget_class, close_new_event_widget);
+  gtk_widget_class_bind_template_callback (widget_class, day_selected);
   gtk_widget_class_bind_template_callback (widget_class, event_activated);
 
   /* Edit dialog related */
@@ -1081,19 +1073,13 @@ gcal_window_init (GcalWindow *self)
 
   self->views[GCAL_WINDOW_VIEW_WEEK] = self->week_view;
   self->views[GCAL_WINDOW_VIEW_MONTH] = self->month_view;
-  self->views[GCAL_WINDOW_VIEW_YEAR] = self->year_view;
 
   self->active_date = g_date_time_new_from_unix_local (0);
   self->rtl = gtk_widget_get_direction (GTK_WIDGET (self)) == GTK_TEXT_DIR_RTL;
 
   /* devel styling */
   if (g_strcmp0 (PROFILE, "Devel") == 0)
-  {
-      GtkStyleContext *style_context;
-
-      style_context = gtk_widget_get_style_context (GTK_WIDGET (self));
-      gtk_style_context_add_class (style_context, "devel");
-  }
+    gtk_widget_add_css_class (GTK_WIDGET (self), "devel");
 
   gtk_widget_set_parent (self->quick_add_popover, GTK_WIDGET (self));
 }
